#################################################
#   Copyright (C) 2005 by Brian Arnold
#   brian@ae6gn.com
#
#   This program is free software; you can redistribute it and/or modify
#   it under the terms of the GNU General Public License as published by
#   the Free Software Foundation; either version 2 of the License, or
#   (at your option) any later version.
#
#   This program is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.
#
#   You should have received a copy of the GNU General Public License
#   along with this program; if not, write to the
#   Free Software Foundation, Inc.,
#   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
#################################################

# Form implementation generated from reading ui file '../stecker.ui'
#
# Created: Thu Sep 8 22:09:37 2005
#      by: The QtRuby User Interface Compiler (rbuic)
#
# WARNING! All changes made in this file will be lost!


# require 'Korundum'

class SteckerBoard < KDE::Dialog

    slots 'languageChange()',
    'steckerA()',
    'steckerB()',
    'steckerC()',
    'steckerD()',
    'steckerE()',
    'steckerF()',
    'steckerG()',
    'steckerH()',
    'steckerI()',
    'steckerJ()',
    'steckerK()',
    'steckerL()',
    'steckerM()',
    'steckerN()',
    'steckerO()',
    'steckerQ()',
    'steckerP()',
    'steckerR()',
    'steckerS()',
    'steckerU()',
    'steckerT()',
    'steckerV()',
    'steckerW()',
    'steckerX()',
    'steckerY()',
    'steckerZ()',
    'resetSteckers()'

    attr_reader :steckerD
    attr_reader :kActiveLabel1_2_2
    attr_reader :steckerB
    attr_reader :kActiveLabel1_3
    attr_reader :steckerA
    attr_reader :steckerC
    attr_reader :kActiveLabel1
    attr_reader :kActiveLabel1_2
    attr_reader :steckerE
    attr_reader :kActiveLabel1_4
    attr_reader :kActiveLabel1_2_3
    attr_reader :steckerF
    attr_reader :steckerG
    attr_reader :kActiveLabel1_3_2
    attr_reader :kActiveLabel1_5
    attr_reader :steckerH
    attr_reader :kActiveLabel1_2_2_3
    attr_reader :kActiveLabel1_3_3
    attr_reader :steckerK
    attr_reader :kActiveLabel1_3_2_2
    attr_reader :steckerJ
    attr_reader :steckerI
    attr_reader :steckerL
    attr_reader :kActiveLabel1_2_4
    attr_reader :kActiveLabel1_2_5_2
    attr_reader :steckerM
    attr_reader :steckerO
    attr_reader :steckerP
    attr_reader :kActiveLabel1_4_2
    attr_reader :steckerN
    attr_reader :kActiveLabel1_6_2
    attr_reader :kActiveLabel1_2_3_2
    attr_reader :steckerQ
    attr_reader :steckerR
    attr_reader :kActiveLabel1_3_4
    attr_reader :kActiveLabel1_6
    attr_reader :kActiveLabel1_2_5
    attr_reader :steckerS
    attr_reader :kActiveLabel1_2_2_4
    attr_reader :steckerT
    attr_reader :steckerX
    attr_reader :kActiveLabel1_3_4_2
    attr_reader :kActiveLabel1_4_3
    attr_reader :steckerU
    attr_reader :kActiveLabel1_2_2_4_2
    attr_reader :kActiveLabel1_4_3_2
    attr_reader :steckerY
    attr_reader :steckerZ
    attr_reader :steckerV
    attr_reader :kActiveLabel1_2_3_3
    attr_reader :steckerW
    attr_reader :kActiveLabel1_3_2_3
    attr_reader :resetSteckers
    attr_reader :kSeparator1
    attr_reader :kActiveLabel2


    attr_writer :a
    attr_reader :a
    attr_writer :b
    attr_reader :b
    attr_writer :c
    attr_reader :c
    attr_writer :d
    attr_reader :d
    attr_writer :e
    attr_reader :e
    attr_writer :f
    attr_reader :f
    attr_writer :g
    attr_reader :g
    attr_writer :h
    attr_reader :h
    attr_writer :i
    attr_reader :i
    attr_writer :j
    attr_reader :j
    attr_writer :k
    attr_reader :k
    attr_writer :l
    attr_reader :l
    attr_writer :m
    attr_reader :m
    attr_writer :n
    attr_reader :n
    attr_writer :o
    attr_reader :o
    attr_writer :p
    attr_reader :p
    attr_writer :q
    attr_reader :q
    attr_writer :r
    attr_reader :r
    attr_writer :s
    attr_reader :s
    attr_writer :t
    attr_reader :t
    attr_writer :u
    attr_reader :u
    attr_writer :v
    attr_reader :v
    attr_writer :w
    attr_reader :w
    attr_writer :x
    attr_reader :x
    attr_writer :y
    attr_reader :y
    attr_writer :z
    attr_reader :z


    def initialize(parent = nil, name = nil, modal = false, fl = 0)
        super

        if name.nil?
        	setName("SteckerBoard")
        end


        @steckerD = KDE::ComboBox.new(self, "steckerD")
        @steckerD.setGeometry( Qt::Rect.new(60, 160, 45, 21) )
        @steckerD_font = Qt::Font.new(@steckerD.font())
        @steckerD_font.setPointSize(12)
        @steckerD.setFont(@steckerD_font)

        @kActiveLabel1_2_2 = KDE::ActiveLabel.new(self, "kActiveLabel1_2_2")
        @kActiveLabel1_2_2.setGeometry( Qt::Rect.new(11, 158, 48, 22) )
        @kActiveLabel1_2_2_font = Qt::Font.new(@kActiveLabel1_2_2.font())
        @kActiveLabel1_2_2_font.setPointSize(12)
        @kActiveLabel1_2_2.setFont(@kActiveLabel1_2_2_font)

        @steckerB = KDE::ComboBox.new(self, "steckerB")
        @steckerB.setGeometry( Qt::Rect.new(60, 100, 45, 21) )
        @steckerB_font = Qt::Font.new(@steckerB.font())
        @steckerB_font.setPointSize(12)
        @steckerB.setFont(@steckerB_font)

        @kActiveLabel1_3 = KDE::ActiveLabel.new(self, "kActiveLabel1_3")
        @kActiveLabel1_3.setGeometry( Qt::Rect.new(11, 128, 48, 22) )
        @kActiveLabel1_3_font = Qt::Font.new(@kActiveLabel1_3.font())
        @kActiveLabel1_3_font.setPointSize(12)
        @kActiveLabel1_3.setFont(@kActiveLabel1_3_font)

        @steckerA = KDE::ComboBox.new(self, "steckerA")
        @steckerA.setGeometry( Qt::Rect.new(60, 70, 45, 21) )
        @steckerA_font = Qt::Font.new(@steckerA.font())
        @steckerA_font.setPointSize(12)
        @steckerA.setFont(@steckerA_font)

        @steckerC = KDE::ComboBox.new(self, "steckerC")
        @steckerC.setGeometry( Qt::Rect.new(60, 130, 45, 21) )
        @steckerC_font = Qt::Font.new(@steckerC.font())
        @steckerC_font.setPointSize(12)
        @steckerC.setFont(@steckerC_font)

        @kActiveLabel1 = KDE::ActiveLabel.new(self, "kActiveLabel1")
        @kActiveLabel1.setGeometry( Qt::Rect.new(11, 68, 48, 22) )
        @kActiveLabel1_font = Qt::Font.new(@kActiveLabel1.font())
        @kActiveLabel1_font.setPointSize(12)
        @kActiveLabel1.setFont(@kActiveLabel1_font)

        @kActiveLabel1_2 = KDE::ActiveLabel.new(self, "kActiveLabel1_2")
        @kActiveLabel1_2.setGeometry( Qt::Rect.new(11, 98, 48, 22) )
        @kActiveLabel1_2_font = Qt::Font.new(@kActiveLabel1_2.font())
        @kActiveLabel1_2_font.setPointSize(12)
        @kActiveLabel1_2.setFont(@kActiveLabel1_2_font)

        @steckerE = KDE::ComboBox.new(self, "steckerE")
        @steckerE.setGeometry( Qt::Rect.new(170, 70, 45, 21) )
        @steckerE_font = Qt::Font.new(@steckerE.font())
        @steckerE_font.setPointSize(12)
        @steckerE.setFont(@steckerE_font)

        @kActiveLabel1_4 = KDE::ActiveLabel.new(self, "kActiveLabel1_4")
        @kActiveLabel1_4.setGeometry( Qt::Rect.new(121, 68, 48, 22) )
        @kActiveLabel1_4_font = Qt::Font.new(@kActiveLabel1_4.font())
        @kActiveLabel1_4_font.setPointSize(12)
        @kActiveLabel1_4.setFont(@kActiveLabel1_4_font)

        @kActiveLabel1_2_3 = KDE::ActiveLabel.new(self, "kActiveLabel1_2_3")
        @kActiveLabel1_2_3.setGeometry( Qt::Rect.new(121, 98, 48, 22) )
        @kActiveLabel1_2_3_font = Qt::Font.new(@kActiveLabel1_2_3.font())
        @kActiveLabel1_2_3_font.setPointSize(12)
        @kActiveLabel1_2_3.setFont(@kActiveLabel1_2_3_font)

        @steckerF = KDE::ComboBox.new(self, "steckerF")
        @steckerF.setGeometry( Qt::Rect.new(170, 100, 45, 21) )
        @steckerF_font = Qt::Font.new(@steckerF.font())
        @steckerF_font.setPointSize(12)
        @steckerF.setFont(@steckerF_font)

        @steckerG = KDE::ComboBox.new(self, "steckerG")
        @steckerG.setGeometry( Qt::Rect.new(170, 130, 45, 21) )
        @steckerG_font = Qt::Font.new(@steckerG.font())
        @steckerG_font.setPointSize(12)
        @steckerG.setFont(@steckerG_font)

        @kActiveLabel1_3_2 = KDE::ActiveLabel.new(self, "kActiveLabel1_3_2")
        @kActiveLabel1_3_2.setGeometry( Qt::Rect.new(121, 128, 48, 22) )
        @kActiveLabel1_3_2_font = Qt::Font.new(@kActiveLabel1_3_2.font())
        @kActiveLabel1_3_2_font.setPointSize(12)
        @kActiveLabel1_3_2.setFont(@kActiveLabel1_3_2_font)

        @kActiveLabel1_5 = KDE::ActiveLabel.new(self, "kActiveLabel1_5")
        @kActiveLabel1_5.setGeometry( Qt::Rect.new(121, 158, 48, 22) )
        @kActiveLabel1_5_font = Qt::Font.new(@kActiveLabel1_5.font())
        @kActiveLabel1_5_font.setPointSize(12)
        @kActiveLabel1_5.setFont(@kActiveLabel1_5_font)

        @steckerH = KDE::ComboBox.new(self, "steckerH")
        @steckerH.setGeometry( Qt::Rect.new(170, 160, 45, 21) )
        @steckerH_font = Qt::Font.new(@steckerH.font())
        @steckerH_font.setPointSize(12)
        @steckerH.setFont(@steckerH_font)

        @kActiveLabel1_2_2_3 = KDE::ActiveLabel.new(self, "kActiveLabel1_2_2_3")
        @kActiveLabel1_2_2_3.setGeometry( Qt::Rect.new(231, 158, 48, 22) )
        @kActiveLabel1_2_2_3_font = Qt::Font.new(@kActiveLabel1_2_2_3.font())
        @kActiveLabel1_2_2_3_font.setPointSize(12)
        @kActiveLabel1_2_2_3.setFont(@kActiveLabel1_2_2_3_font)

        @kActiveLabel1_3_3 = KDE::ActiveLabel.new(self, "kActiveLabel1_3_3")
        @kActiveLabel1_3_3.setGeometry( Qt::Rect.new(231, 128, 48, 22) )
        @kActiveLabel1_3_3_font = Qt::Font.new(@kActiveLabel1_3_3.font())
        @kActiveLabel1_3_3_font.setPointSize(12)
        @kActiveLabel1_3_3.setFont(@kActiveLabel1_3_3_font)

        @steckerK = KDE::ComboBox.new(self, "steckerK")
        @steckerK.setGeometry( Qt::Rect.new(280, 130, 45, 21) )
        @steckerK_font = Qt::Font.new(@steckerK.font())
        @steckerK_font.setPointSize(12)
        @steckerK.setFont(@steckerK_font)

        @kActiveLabel1_3_2_2 = KDE::ActiveLabel.new(self, "kActiveLabel1_3_2_2")
        @kActiveLabel1_3_2_2.setGeometry( Qt::Rect.new(231, 98, 48, 22) )
        @kActiveLabel1_3_2_2_font = Qt::Font.new(@kActiveLabel1_3_2_2.font())
        @kActiveLabel1_3_2_2_font.setPointSize(12)
        @kActiveLabel1_3_2_2.setFont(@kActiveLabel1_3_2_2_font)

        @steckerJ = KDE::ComboBox.new(self, "steckerJ")
        @steckerJ.setGeometry( Qt::Rect.new(280, 100, 45, 21) )
        @steckerJ_font = Qt::Font.new(@steckerJ.font())
        @steckerJ_font.setPointSize(12)
        @steckerJ.setFont(@steckerJ_font)

        @steckerI = KDE::ComboBox.new(self, "steckerI")
        @steckerI.setGeometry( Qt::Rect.new(280, 70, 45, 21) )
        @steckerI_font = Qt::Font.new(@steckerI.font())
        @steckerI_font.setPointSize(12)
        @steckerI.setFont(@steckerI_font)

        @steckerL = KDE::ComboBox.new(self, "steckerL")
        @steckerL.setGeometry( Qt::Rect.new(280, 160, 45, 21) )
        @steckerL_font = Qt::Font.new(@steckerL.font())
        @steckerL_font.setPointSize(12)
        @steckerL.setFont(@steckerL_font)

        @kActiveLabel1_2_4 = KDE::ActiveLabel.new(self, "kActiveLabel1_2_4")
        @kActiveLabel1_2_4.setGeometry( Qt::Rect.new(231, 68, 48, 22) )
        @kActiveLabel1_2_4_font = Qt::Font.new(@kActiveLabel1_2_4.font())
        @kActiveLabel1_2_4_font.setPointSize(12)
        @kActiveLabel1_2_4.setFont(@kActiveLabel1_2_4_font)

        @kActiveLabel1_2_5_2 = KDE::ActiveLabel.new(self, "kActiveLabel1_2_5_2")
        @kActiveLabel1_2_5_2.setGeometry( Qt::Rect.new(341, 158, 48, 22) )
        @kActiveLabel1_2_5_2_font = Qt::Font.new(@kActiveLabel1_2_5_2.font())
        @kActiveLabel1_2_5_2_font.setPointSize(12)
        @kActiveLabel1_2_5_2.setFont(@kActiveLabel1_2_5_2_font)

        @steckerM = KDE::ComboBox.new(self, "steckerM")
        @steckerM.setGeometry( Qt::Rect.new(390, 70, 45, 21) )
        @steckerM_font = Qt::Font.new(@steckerM.font())
        @steckerM_font.setPointSize(12)
        @steckerM.setFont(@steckerM_font)

        @steckerO = KDE::ComboBox.new(self, "steckerO")
        @steckerO.setGeometry( Qt::Rect.new(390, 130, 45, 21) )
        @steckerO_font = Qt::Font.new(@steckerO.font())
        @steckerO_font.setPointSize(12)
        @steckerO.setFont(@steckerO_font)

        @steckerP = KDE::ComboBox.new(self, "steckerP")
        @steckerP.setGeometry( Qt::Rect.new(390, 160, 45, 21) )
        @steckerP_font = Qt::Font.new(@steckerP.font())
        @steckerP_font.setPointSize(12)
        @steckerP.setFont(@steckerP_font)

        @kActiveLabel1_4_2 = KDE::ActiveLabel.new(self, "kActiveLabel1_4_2")
        @kActiveLabel1_4_2.setGeometry( Qt::Rect.new(341, 68, 49, 22) )
        @kActiveLabel1_4_2_font = Qt::Font.new(@kActiveLabel1_4_2.font())
        @kActiveLabel1_4_2_font.setPointSize(12)
        @kActiveLabel1_4_2.setFont(@kActiveLabel1_4_2_font)

        @steckerN = KDE::ComboBox.new(self, "steckerN")
        @steckerN.setGeometry( Qt::Rect.new(390, 100, 45, 21) )
        @steckerN_font = Qt::Font.new(@steckerN.font())
        @steckerN_font.setPointSize(12)
        @steckerN.setFont(@steckerN_font)

        @kActiveLabel1_6_2 = KDE::ActiveLabel.new(self, "kActiveLabel1_6_2")
        @kActiveLabel1_6_2.setGeometry( Qt::Rect.new(341, 128, 48, 22) )
        @kActiveLabel1_6_2_font = Qt::Font.new(@kActiveLabel1_6_2.font())
        @kActiveLabel1_6_2_font.setPointSize(12)
        @kActiveLabel1_6_2.setFont(@kActiveLabel1_6_2_font)

        @kActiveLabel1_2_3_2 = KDE::ActiveLabel.new(self, "kActiveLabel1_2_3_2")
        @kActiveLabel1_2_3_2.setGeometry( Qt::Rect.new(341, 98, 48, 22) )
        @kActiveLabel1_2_3_2_font = Qt::Font.new(@kActiveLabel1_2_3_2.font())
        @kActiveLabel1_2_3_2_font.setPointSize(12)
        @kActiveLabel1_2_3_2.setFont(@kActiveLabel1_2_3_2_font)

        @steckerQ = KDE::ComboBox.new(self, "steckerQ")
        @steckerQ.setGeometry( Qt::Rect.new(500, 70, 45, 21) )
        @steckerQ_font = Qt::Font.new(@steckerQ.font())
        @steckerQ_font.setPointSize(12)
        @steckerQ.setFont(@steckerQ_font)

        @steckerR = KDE::ComboBox.new(self, "steckerR")
        @steckerR.setGeometry( Qt::Rect.new(500, 100, 45, 21) )
        @steckerR_font = Qt::Font.new(@steckerR.font())
        @steckerR_font.setPointSize(12)
        @steckerR.setFont(@steckerR_font)

        @kActiveLabel1_3_4 = KDE::ActiveLabel.new(self, "kActiveLabel1_3_4")
        @kActiveLabel1_3_4.setGeometry( Qt::Rect.new(451, 128, 48, 22) )
        @kActiveLabel1_3_4_font = Qt::Font.new(@kActiveLabel1_3_4.font())
        @kActiveLabel1_3_4_font.setPointSize(12)
        @kActiveLabel1_3_4.setFont(@kActiveLabel1_3_4_font)

        @kActiveLabel1_6 = KDE::ActiveLabel.new(self, "kActiveLabel1_6")
        @kActiveLabel1_6.setGeometry( Qt::Rect.new(451, 68, 48, 22) )
        @kActiveLabel1_6_font = Qt::Font.new(@kActiveLabel1_6.font())
        @kActiveLabel1_6_font.setPointSize(12)
        @kActiveLabel1_6.setFont(@kActiveLabel1_6_font)

        @kActiveLabel1_2_5 = KDE::ActiveLabel.new(self, "kActiveLabel1_2_5")
        @kActiveLabel1_2_5.setGeometry( Qt::Rect.new(451, 98, 48, 22) )
        @kActiveLabel1_2_5_font = Qt::Font.new(@kActiveLabel1_2_5.font())
        @kActiveLabel1_2_5_font.setPointSize(12)
        @kActiveLabel1_2_5.setFont(@kActiveLabel1_2_5_font)

        @steckerS = KDE::ComboBox.new(self, "steckerS")
        @steckerS.setGeometry( Qt::Rect.new(500, 130, 45, 21) )
        @steckerS_font = Qt::Font.new(@steckerS.font())
        @steckerS_font.setPointSize(12)
        @steckerS.setFont(@steckerS_font)

        @kActiveLabel1_2_2_4 = KDE::ActiveLabel.new(self, "kActiveLabel1_2_2_4")
        @kActiveLabel1_2_2_4.setGeometry( Qt::Rect.new(451, 158, 48, 22) )
        @kActiveLabel1_2_2_4_font = Qt::Font.new(@kActiveLabel1_2_2_4.font())
        @kActiveLabel1_2_2_4_font.setPointSize(12)
        @kActiveLabel1_2_2_4.setFont(@kActiveLabel1_2_2_4_font)

        @steckerT = KDE::ComboBox.new(self, "steckerT")
        @steckerT.setGeometry( Qt::Rect.new(500, 160, 45, 21) )
        @steckerT_font = Qt::Font.new(@steckerT.font())
        @steckerT_font.setPointSize(12)
        @steckerT.setFont(@steckerT_font)

        @steckerX = KDE::ComboBox.new(self, "steckerX")
        @steckerX.setGeometry( Qt::Rect.new(610, 160, 45, 21) )
        @steckerX_font = Qt::Font.new(@steckerX.font())
        @steckerX_font.setPointSize(12)
        @steckerX.setFont(@steckerX_font)

        @kActiveLabel1_3_4_2 = KDE::ActiveLabel.new(self, "kActiveLabel1_3_4_2")
        @kActiveLabel1_3_4_2.setGeometry( Qt::Rect.new(561, 158, 48, 22) )
        @kActiveLabel1_3_4_2_font = Qt::Font.new(@kActiveLabel1_3_4_2.font())
        @kActiveLabel1_3_4_2_font.setPointSize(12)
        @kActiveLabel1_3_4_2.setFont(@kActiveLabel1_3_4_2_font)

        @kActiveLabel1_4_3 = KDE::ActiveLabel.new(self, "kActiveLabel1_4_3")
        @kActiveLabel1_4_3.setGeometry( Qt::Rect.new(561, 68, 48, 22) )
        @kActiveLabel1_4_3_font = Qt::Font.new(@kActiveLabel1_4_3.font())
        @kActiveLabel1_4_3_font.setPointSize(12)
        @kActiveLabel1_4_3.setFont(@kActiveLabel1_4_3_font)

        @steckerU = KDE::ComboBox.new(self, "steckerU")
        @steckerU.setGeometry( Qt::Rect.new(610, 70, 45, 21) )
        @steckerU_font = Qt::Font.new(@steckerU.font())
        @steckerU_font.setPointSize(12)
        @steckerU.setFont(@steckerU_font)

        @kActiveLabel1_2_2_4_2 = KDE::ActiveLabel.new(self, "kActiveLabel1_2_2_4_2")
        @kActiveLabel1_2_2_4_2.setGeometry( Qt::Rect.new(671, 68, 48, 22) )
        @kActiveLabel1_2_2_4_2_font = Qt::Font.new(@kActiveLabel1_2_2_4_2.font())
        @kActiveLabel1_2_2_4_2_font.setPointSize(12)
        @kActiveLabel1_2_2_4_2.setFont(@kActiveLabel1_2_2_4_2_font)

        @kActiveLabel1_4_3_2 = KDE::ActiveLabel.new(self, "kActiveLabel1_4_3_2")
        @kActiveLabel1_4_3_2.setGeometry( Qt::Rect.new(671, 98, 48, 22) )
        @kActiveLabel1_4_3_2_font = Qt::Font.new(@kActiveLabel1_4_3_2.font())
        @kActiveLabel1_4_3_2_font.setPointSize(12)
        @kActiveLabel1_4_3_2.setFont(@kActiveLabel1_4_3_2_font)

        @steckerY = KDE::ComboBox.new(self, "steckerY")
        @steckerY.setGeometry( Qt::Rect.new(720, 70, 45, 21) )
        @steckerY_font = Qt::Font.new(@steckerY.font())
        @steckerY_font.setPointSize(12)
        @steckerY.setFont(@steckerY_font)

        @steckerZ = KDE::ComboBox.new(self, "steckerZ")
        @steckerZ.setGeometry( Qt::Rect.new(720, 100, 45, 21) )
        @steckerZ_font = Qt::Font.new(@steckerZ.font())
        @steckerZ_font.setPointSize(12)
        @steckerZ.setFont(@steckerZ_font)

        @steckerV = KDE::ComboBox.new(self, "steckerV")
        @steckerV.setGeometry( Qt::Rect.new(610, 100, 45, 21) )
        @steckerV_font = Qt::Font.new(@steckerV.font())
        @steckerV_font.setPointSize(12)
        @steckerV.setFont(@steckerV_font)

        @kActiveLabel1_2_3_3 = KDE::ActiveLabel.new(self, "kActiveLabel1_2_3_3")
        @kActiveLabel1_2_3_3.setGeometry( Qt::Rect.new(561, 98, 48, 22) )
        @kActiveLabel1_2_3_3_font = Qt::Font.new(@kActiveLabel1_2_3_3.font())
        @kActiveLabel1_2_3_3_font.setPointSize(12)
        @kActiveLabel1_2_3_3.setFont(@kActiveLabel1_2_3_3_font)

        @steckerW = KDE::ComboBox.new(self, "steckerW")
        @steckerW.setGeometry( Qt::Rect.new(610, 130, 45, 21) )
        @steckerW_font = Qt::Font.new(@steckerW.font())
        @steckerW_font.setPointSize(12)
        @steckerW.setFont(@steckerW_font)

        @kActiveLabel1_3_2_3 = KDE::ActiveLabel.new(self, "kActiveLabel1_3_2_3")
        @kActiveLabel1_3_2_3.setGeometry( Qt::Rect.new(559, 128, 51, 22) )
        @kActiveLabel1_3_2_3_font = Qt::Font.new(@kActiveLabel1_3_2_3.font())
        @kActiveLabel1_3_2_3_font.setPointSize(12)
        @kActiveLabel1_3_2_3.setFont(@kActiveLabel1_3_2_3_font)

        @resetSteckers = KDE::PushButton.new(self, "resetSteckers")
        @resetSteckers.setGeometry( Qt::Rect.new(670, 130, 95, 51) )
        @resetSteckers_font = Qt::Font.new(@resetSteckers.font())
        @resetSteckers_font.setPointSize(13)
        @resetSteckers.setFont(@resetSteckers_font)

        @kSeparator1 = KDE::Separator.new(self, "kSeparator1")
        @kSeparator1.setGeometry( Qt::Rect.new(10, 40, 760, 21) )

        @kActiveLabel2 = KDE::ActiveLabel.new(self, "kActiveLabel2")
        @kActiveLabel2.setGeometry( Qt::Rect.new(280, 0, 212, 41) )
        @kActiveLabel2_font = Qt::Font.new(@kActiveLabel2.font())
        @kActiveLabel2_font.setPointSize(25)
        @kActiveLabel2.setFont(@kActiveLabel2_font)
        languageChange()
        resize( Qt::Size.new(778, 192).expandedTo(minimumSizeHint()) )
        clearWState( WState_Polished )

        Qt::Object.connect(@steckerA, SIGNAL("activated(const QString&)"), self, SLOT("steckerA()") )
        Qt::Object.connect(@steckerB, SIGNAL("activated(const QString&)"), self, SLOT("steckerB()") )
        Qt::Object.connect(@steckerC, SIGNAL("activated(const QString&)"), self, SLOT("steckerC()") )
        Qt::Object.connect(@steckerD, SIGNAL("activated(const QString&)"), self, SLOT("steckerD()") )
        Qt::Object.connect(@steckerE, SIGNAL("activated(const QString&)"), self, SLOT("steckerE()") )
        Qt::Object.connect(@steckerF, SIGNAL("activated(const QString&)"), self, SLOT("steckerF()") )
        Qt::Object.connect(@steckerG, SIGNAL("activated(const QString&)"), self, SLOT("steckerG()") )
        Qt::Object.connect(@steckerH, SIGNAL("activated(const QString&)"), self, SLOT("steckerH()") )
        Qt::Object.connect(@steckerI, SIGNAL("activated(const QString&)"), self, SLOT("steckerI()") )
        Qt::Object.connect(@steckerJ, SIGNAL("activated(const QString&)"), self, SLOT("steckerJ()") )
        Qt::Object.connect(@steckerK, SIGNAL("activated(const QString&)"), self, SLOT("steckerK()") )
        Qt::Object.connect(@steckerL, SIGNAL("activated(const QString&)"), self, SLOT("steckerL()") )
        Qt::Object.connect(@steckerM, SIGNAL("activated(const QString&)"), self, SLOT("steckerM()") )
        Qt::Object.connect(@steckerN, SIGNAL("activated(const QString&)"), self, SLOT("steckerN()") )
        Qt::Object.connect(@steckerO, SIGNAL("activated(const QString&)"), self, SLOT("steckerO()") )
        Qt::Object.connect(@steckerP, SIGNAL("activated(const QString&)"), self, SLOT("steckerP()") )
        Qt::Object.connect(@steckerQ, SIGNAL("activated(const QString&)"), self, SLOT("steckerQ()") )
        Qt::Object.connect(@steckerR, SIGNAL("activated(const QString&)"), self, SLOT("steckerR()") )
        Qt::Object.connect(@steckerS, SIGNAL("activated(const QString&)"), self, SLOT("steckerS()") )
        Qt::Object.connect(@steckerT, SIGNAL("activated(const QString&)"), self, SLOT("steckerT()") )
        Qt::Object.connect(@steckerU, SIGNAL("activated(const QString&)"), self, SLOT("steckerU()") )
        Qt::Object.connect(@steckerV, SIGNAL("activated(const QString&)"), self, SLOT("steckerV()") )
        Qt::Object.connect(@steckerW, SIGNAL("activated(const QString&)"), self, SLOT("steckerW()") )
        Qt::Object.connect(@steckerX, SIGNAL("activated(const QString&)"), self, SLOT("steckerX()") )
        Qt::Object.connect(@steckerY, SIGNAL("activated(const QString&)"), self, SLOT("steckerY()") )
        Qt::Object.connect(@steckerZ, SIGNAL("activated(const QString&)"), self, SLOT("steckerZ()") )
        Qt::Object.connect(@resetSteckers, SIGNAL("clicked()"), self, SLOT("resetSteckers()") )



        # Stecker Ini.
        for i in 65..90
		   @steckerA.insertItem(i.chr)
        end
        @steckerA.setCurrentItem(0)

        for i in 65..90
		   @steckerB.insertItem(i.chr)
        end
        @steckerB.setCurrentItem(1)

        for i in 65..90
		   @steckerC.insertItem(i.chr)
        end
        @steckerC.setCurrentItem(2)

        for i in 65..90
		   @steckerD.insertItem(i.chr)
        end
        @steckerD.setCurrentItem(3)

        for i in 65..90
		   @steckerE.insertItem(i.chr)
        end
        @steckerE.setCurrentItem(4)

        for i in 65..90
           @steckerF.insertItem(i.chr)
        end
        @steckerF.setCurrentItem(5)

        for i in 65..90
		   @steckerG.insertItem(i.chr)
        end
        @steckerG.setCurrentItem(6)

        for i in 65..90
		   @steckerH.insertItem(i.chr)
        end
        @steckerH.setCurrentItem(7)

        for i in 65..90
		   @steckerI.insertItem(i.chr)
        end
        @steckerI.setCurrentItem(8)

        for i in 65..90
		   @steckerJ.insertItem(i.chr)
        end
        @steckerJ.setCurrentItem(9)

        for i in 65..90
		   @steckerK.insertItem(i.chr)
        end
        @steckerK.setCurrentItem(10)

        for i in 65..90
		   @steckerL.insertItem(i.chr)
        end
        @steckerL.setCurrentItem(11)

        for i in 65..90
		   @steckerM.insertItem(i.chr)
        end
        @steckerM.setCurrentItem(12)

        for i in 65..90
		   @steckerN.insertItem(i.chr)
        end
        @steckerN.setCurrentItem(13)

        for i in 65..90
		   @steckerO.insertItem(i.chr)
        end
        @steckerO.setCurrentItem(14)

        for i in 65..90
		   @steckerP.insertItem(i.chr)
        end
        @steckerP.setCurrentItem(15)

        for i in 65..90
		   @steckerQ.insertItem(i.chr)
        end
        @steckerQ.setCurrentItem(16)

        for i in 65..90
		   @steckerR.insertItem(i.chr)
        end
        @steckerR.setCurrentItem(17)

        for i in 65..90
		   @steckerS.insertItem(i.chr)
        end
        @steckerS.setCurrentItem(18)

        for i in 65..90
		   @steckerT.insertItem(i.chr)
        end
        @steckerT.setCurrentItem(19)

        for i in 65..90
		   @steckerU.insertItem(i.chr)
        end
        @steckerU.setCurrentItem(20)

        for i in 65..90
		   @steckerV.insertItem(i.chr)
        end
        @steckerV.setCurrentItem(21)

        for i in 65..90
		   @steckerW.insertItem(i.chr)
        end
        @steckerW.setCurrentItem(22)

        for i in 65..90
		   @steckerX.insertItem(i.chr)
        end
        @steckerX.setCurrentItem(23)

        for i in 65..90
		   @steckerY.insertItem(i.chr)
        end
        @steckerY.setCurrentItem(24)

        for i in 65..90
		   @steckerZ.insertItem(i.chr)
        end
        @steckerZ.setCurrentItem(25)
    end

    #
    #  Sets the strings of the subwidgets using the current
    #  language.
    #
    def languageChange()
        setCaption(trUtf8("Stecker Board - KEnigma"))
        @kActiveLabel1_2_2.setText( trUtf8("D -->") )
        @kActiveLabel1_3.setText( trUtf8("C -->") )
        @kActiveLabel1.setText( trUtf8("A -->") )
        @kActiveLabel1_2.setText( trUtf8("B -->") )
        @kActiveLabel1_4.setText( trUtf8("E -->") )
        @kActiveLabel1_2_3.setText( trUtf8("F -->") )
        @kActiveLabel1_3_2.setText( trUtf8("G -->") )
        @kActiveLabel1_5.setText( trUtf8("H -->") )
        @kActiveLabel1_2_2_3.setText( trUtf8("L -->") )
        @kActiveLabel1_3_3.setText( trUtf8("K -->") )
        @kActiveLabel1_3_2_2.setText( trUtf8("J -->") )
        @kActiveLabel1_2_4.setText( trUtf8("I -->") )
        @kActiveLabel1_2_5_2.setText( trUtf8("P -->") )
        @kActiveLabel1_4_2.setText( trUtf8("M -->") )
        @kActiveLabel1_6_2.setText( trUtf8("O -->") )
        @kActiveLabel1_2_3_2.setText( trUtf8("N -->") )
        @kActiveLabel1_3_4.setText( trUtf8("S -->") )
        @kActiveLabel1_6.setText( trUtf8("Q -->") )
        @kActiveLabel1_2_5.setText( trUtf8("R -->") )
        @kActiveLabel1_2_2_4.setText( trUtf8("T -->") )
        @kActiveLabel1_3_4_2.setText( trUtf8("X -->") )
        @kActiveLabel1_4_3.setText( trUtf8("U -->") )
        @kActiveLabel1_2_2_4_2.setText( trUtf8("Y -->") )
        @kActiveLabel1_4_3_2.setText( trUtf8("Z -->") )
        @kActiveLabel1_2_3_3.setText( trUtf8("V -->") )
        @kActiveLabel1_3_2_3.setText( trUtf8("W -->") )
        @resetSteckers.setText( trUtf8("Reset &all\n" +
        "steckers") )
        @resetSteckers.setAccel( Qt::KeySequence.new(trUtf8("Alt+A")) )
        @kActiveLabel2.setText( trUtf8("Stecker Board") )
    end
    protected :languageChange


    def steckerA(*k)
    	self.a = @steckerA.currentText
    	changeStecker(@steckerA.currentText, 0)
		@IsSet["A"] = true
    end

    def steckerB(*k)
      self.b = @steckerB.currentText
      changeStecker(@steckerB.currentText, 1)
		@IsSet["B"] = true
    end

    def steckerC(*k)
      self.c = @steckerC.currentText
      changeStecker(@steckerC.currentText, 2)
		@IsSet["C"] = true
    end

    def steckerD(*k)
      self.d = @steckerD.currentText
		changeStecker(@steckerD.currentText, 3)
		@IsSet["D"] = true
    end

    def steckerE(*k)
      self.e = @steckerE.currentText
		changeStecker(@steckerE.currentText, 4)
		@IsSet["E"] = true
    end

    def steckerF(*k)
      self.f = @steckerF.currentText
      changeStecker(@steckerF.currentText, 5)
      @IsSet["F"] = true
    end

    def steckerG(*k)
		self.g = @steckerG.currentText
		changeStecker(@steckerG.currentText, 6)
		@IsSet["G"] = true
    end

    def steckerH(*k)
      self.h = @steckerH.currentText
		changeStecker(@steckerH.currentText, 7)
		@IsSet["H"] = true
    end

    def steckerI(*k)
      self.i = @steckerI.currentText
		changeStecker(@steckerI.currentText, 8)
		@IsSet["I"] = true
    end

    def steckerJ(*k)
      self.j = @steckerJ.currentText
		changeStecker(@steckerJ.currentText, 9)
		@IsSet["J"] = true
    end

    def steckerK(*k)
      self.k = @steckerK.currentText
		changeStecker(@steckerK.currentText, 10)
		@IsSet["K"] = true
    end

    def steckerL(*k)
      self.l = @steckerL.currentText
		changeStecker(@steckerL.currentText, 11)
		@IsSet["L"] = true
    end

    def steckerM(*k)
      self.m = @steckerM.currentText
		changeStecker(@steckerM.currentText, 12)
		@IsSet["M"] = true
    end

    def steckerN(*k)
      self.n = @steckerN.currentText
		changeStecker(@steckerN.currentText, 13)
		@IsSet["N"] = true
    end

    def steckerO(*k)
      self.o = @steckerO.currentText
		changeStecker(@steckerO.currentText, 14)
		@IsSet["O"] = true
    end

    def steckerP(*k)
      self.p = @steckerP.currentText
		changeStecker(@steckerP.currentText, 15)
		@IsSet["P"] = true
    end

    def steckerQ(*k)
      self.q = @steckerQ.currentText
		changeStecker(@steckerQ.currentText, 16)
		@IsSet["Q"] = true
    end

    def steckerR(*k)
      self.r = @steckerR.currentText
		changeStecker(@steckerR.currentText, 17)
		@IsSet["R"] = true
    end

    def steckerS(*k)
      self.s = @steckerS.currentText
		changeStecker(@steckerS.currentText, 18)
		@IsSet["S"] = true
    end

    def steckerT(*k)
      self.t = @steckerT.currentText
		changeStecker(@steckerT.currentText, 19)
		@IsSet["T"] = true
    end

    def steckerU(*k)
      self.u = @steckerU.currentText
		changeStecker(@steckerU.currentText, 20)
		@IsSet["U"] = true
    end

    def steckerV(*k)
      self.v = @steckerV.currentText
		changeStecker(@steckerV.currentText, 21)
		@IsSet["V"] = true
    end

    def steckerW(*k)
      self.w = @steckerW.currentText
		changeStecker(@steckerW.currentText, 22)
		@IsSet["W"] = true
    end

    def steckerX(*k)
    	self.x = @steckerX.currentText
      changeStecker(@steckerX.currentText, 23)
      @IsSet["X"] = true
    end

    def steckerY(*k)
      self.y = @steckerY.currentText
      changeStecker(@steckerY.currentText, 24)
      @IsSet["Y"] = true
    end

    def steckerZ(*k)
      self.z = @steckerZ.currentText
      changeStecker(@steckerZ.currentText, 25)
      @IsSet["Z"] = true
    end

    def changeStecker(letter, num)
    	if @IsSet[letter] == true then
    		case letter
    			when "A"
    				letter2 = @steckerA.currentText
    			when "B"
	    			letter2 = @steckerB.currentText
    			when "C"
    				letter2 = @steckerC.currentText
	    		when "D"
    				letter2 = @steckerD.currentText
    			when "E"
    				letter2 = @steckerE.currentText
    			when "F"
    				letter2 = @steckerF.currentText
	    		when "G"
    				letter2 = @steckerG.currentText
    			when "H"
	    			letter2 = @steckerH.currentText
    			when "I"
    				letter2 = @steckerI.currentText
	    		when "J"
    				letter2 = @steckerJ.currentText
    			when "K"
	    			letter2 = @steckerK.currentText
    			when "L"
    				letter2 = @steckerL.currentText
	    		when "M"
    				letter2 = @steckerM.currentText
    			when "N"
	    			letter2 = @steckerN.currentText
    			when "O"
    				letter2 = @steckerO.currentText
	    		when "P"
    				letter2 = @steckerP.currentText
    			when "Q"
	    			letter2 = @steckerQ.currentText
    			when "R"
    				letter2 = @steckerR.currentText
	    		when "S"
    				letter2 = @steckerS.currentText
    			when "T"
		   		letter2 = @steckerT.currentText
    			when "U"
    				letter2 = @steckerU.currentText
	    		when "V"
    				letter2 = @steckerV.currentText
    			when "W"
    				letter2 = @steckerW.currentText
	    		when "X"
    				letter2 = @steckerX.currentText
    			when "Y"
	    			letter2 = @steckerY.currentText
    			when "Z"
    				letter2 = @steckerZ.currentText
    		end
    	end

    	if @IsSet[letter2] == true then
    		case letter2
    			when "A"
    	 			@steckerA.setCurrentItem(0)
					self.a = @steckerA.currentText
     				@IsSet["A"] = false
	    		when "B"
     				@steckerB.setCurrentItem(1)
     				self.b = @steckerB.currentText
	     			@IsSet["B"] = false
    			when "C"
    				@steckerC.setCurrentItem(2)
	     			self.c = @steckerC.currentText
    	 			@IsSet["C"] = false
    			when "D"
    				@steckerD.setCurrentItem(3)
	     			self.d = @steckerD.currentText
    	 			@IsSet["D"] = false
    			when "E"
    				@steckerE.setCurrentItem(4)
	     			self.e = @steckerE.currentText
    	 			@IsSet["E"] = false
    			when "F"
    				@steckerF.setCurrentItem(5)
	     			self.f = @steckerF.currentText
    	 			@IsSet["C"] = false
	    		when "G"
    				@steckerG.setCurrentItem(6)
	     			self.g = @steckerG.currentText
    	 			@IsSet["G"] = false
    			when "H"
	    			@steckerH.setCurrentItem(7)
	     			self.h = @steckerH.currentText
    	 			@IsSet["H"] = false
    			when "I"
    				@steckerI.setCurrentItem(8)
	     			self.i = @steckerI.currentText
    	 			@IsSet["I"] = false
	    		when "J"
    				@steckerJ.setCurrentItem(9)
	     			self.j = @steckerJ.currentText
    	 			@IsSet["J"] = false
    			when "K"
	    			@steckerK.setCurrentItem(10)
	     			self.k = @steckerK.currentText
    	 			@IsSet["K"] = false
    			when "L"
    				@steckerL.setCurrentItem(11)
	     			self.l = @steckerL.currentText
    	 			@IsSet["L"] = false
	    		when "M"
    				@steckerM.setCurrentItem(12)
	     			self.m = @steckerM.currentText
    	 			@IsSet["M"] = false
    			when "N"
	    			@steckerN.setCurrentItem(13)
	     			self.n = @steckerN.currentText
    	 			@IsSet["N"] = false
    			when "O"
    				@steckerO.setCurrentItem(14)
	     			self.o = @steckerM.currentText
    	 			@IsSet["O"] = false
	    		when "P"
    				@steckeP.setCurrentItem(15)
	     			self.p = @steckerP.currentText
    	 			@IsSet["P"] = false
    			when "Q"
	    			@steckerQ.setCurrentItem(16)
	     			self.q = @steckerQ.currentText
    	 			@IsSet["q"] = false
    			when "R"
    				@steckerR.setCurrentItem(17)
	     			self.r = @steckerR.currentText
    	 			@IsSet["R"] = false
	    		when "S"
    				@steckerS.setCurrentItem(18)
	     			self.s = @steckerS.currentText
    	 			@IsSet["S"] = false
    			when "T"
		   			@steckerT.setCurrentItem(19)
	     			self.t = @steckerT.currentText
    	 			@IsSet["T"] = false
    			when "U"
    				@steckerU.setCurrentItem(20)
	     			self.u = @steckerU.currentText
    	 			@IsSet["U"] = false
	    		when "V"
    				@steckerV.setCurrentItem(21)
	     			self.v = @steckerV.currentText
    	 			@IsSet["V"] = false
    			when "W"
	    			@steckerW.setCurrentItem(22)
	     			self.w = @steckerW.currentText
    	 			@IsSet["W"] = false
    			when "X"
    				@steckerX.setCurrentItem(23)
	     			self.x = @steckerX.currentText
    	 			@IsSet["X"] = false
	    		when "Y"
    				@steckerY.setCurrentItem(24)
	     			self.y = @steckerY.currentText
    	 			@IsSet["Y"] = false
    			when "Z"
	    			@steckerZ.setCurrentItem(25)
	     			self.z = @steckerZ.currentText
    	 			@IsSet["Z"] = false
    		end
    	end


    	case letter
    		when "A"
    			@steckerA.setCurrentItem(num)
    			self.a = @steckerA.currentText
    		when "B"
    			@steckerB.setCurrentItem(num)
    			self.b = @steckerB.currentText
    		when "C"
    			@steckerC.setCurrentItem(num)
    			self.c = @steckerC.currentText
    		when "D"
    			@steckerD.setCurrentItem(num)
    			self.d = @steckerD.currentText
    		when "E"
    			@steckerE.setCurrentItem(num)
    			self.e= @steckerE.currentText
    		when "F"
    			@steckerF.setCurrentItem(num)
    			self.f = @steckerF.currentText
    		when "G"
    			@steckerG.setCurrentItem(num)
    			self.g= @steckerG.currentText
    		when "H"
    			@steckerH.setCurrentItem(num)
    			self.h = @steckerH.currentText
    		when "I"
    			@steckerI.setCurrentItem(num)
    			self.i = @steckerI.currentText
    		when "J"
    			@steckerJ.setCurrentItem(num)
    			self.j = @steckerJ.currentText
    		when "K"
    			@steckerK.setCurrentItem(num)
    			self.k = @steckerK.currentText
    		when "L"
    			@steckerL.setCurrentItem(num)
    			self.l = @steckerL.currentText
    		when "M"
    			@steckerM.setCurrentItem(num)
    			self.m = @steckerM.currentText
    		when "N"
    			@steckerN.setCurrentItem(num)
    			self.n = @steckerN.currentText
    		when "O"
    			@steckerO.setCurrentItem(num)
    			self.o = @steckerO.currentText
    		when "P"
    			@steckerP.setCurrentItem(num)
    			self.p = @steckerP.currentText
    		when "Q"
    			@steckerQ.setCurrentItem(num)
    			self.q = @steckerQ.currentText
    		when "R"
    			@steckerR.setCurrentItem(num)
    			self.r = @steckerR.currentText
    		when "S"
    			@steckerS.setCurrentItem(num)
    			self.s = @steckerS.currentText
    		when "T"
    			@steckerT.setCurrentItem(num)
    			self.t = @steckerT.currentText
    		when "U"
    			@steckerU.setCurrentItem(num)
    			self.u = @steckerU.currentText
    		when "V"
    			@steckerV.setCurrentItem(num)
    			self.v = @steckerV.currentText
    		when "W"
    			@steckerW.setCurrentItem(num)
    			self.w = @steckerW.currentText
    		when "X"
    			@steckerX.setCurrentItem(num)
    			self.x = @steckerX.currentText
    		when "Y"
    			@steckerY.setCurrentItem(num)
    			self.y = @steckerY.currentText
    		when "Z"
    			@steckerZ.setCurrentItem(num)
    			self.z = @steckerZ.currentText
    	end
    	@IsSet[letter] = true
    end


    def resetSteckers(*k)
    	@steckerA.setCurrentItem(0)
    	@steckerB.setCurrentItem(1)
    	@steckerC.setCurrentItem(2)
        @steckerD.setCurrentItem(3)
        @steckerE.setCurrentItem(4)
        @steckerF.setCurrentItem(5)
        @steckerG.setCurrentItem(6)
        @steckerH.setCurrentItem(7)
		@steckerI.setCurrentItem(8)
        @steckerJ.setCurrentItem(9)
        @steckerK.setCurrentItem(10)
        @steckerL.setCurrentItem(11)
        @steckerM.setCurrentItem(12)
        @steckerN.setCurrentItem(13)
        @steckerO.setCurrentItem(14)
        @steckerP.setCurrentItem(15)
        @steckerQ.setCurrentItem(16)
        @steckerR.setCurrentItem(17)
        @steckerS.setCurrentItem(18)
        @steckerT.setCurrentItem(19)
        @steckerU.setCurrentItem(20)
        @steckerV.setCurrentItem(21)
		@steckerW.setCurrentItem(22)
		@steckerX.setCurrentItem(23)
        @steckerY.setCurrentItem(24)
        @steckerZ.setCurrentItem(25)
        initStecker()
    end


    def initStecker()
		self.a = "A"
     	self.b = "B"
     	self.c = "C"
     	self.d = "D"
     	self.e = "E"
     	self.f = "F"
     	self.g = "G"
     	self.h = "H"
     	self.i = "I"
     	self.j = "J"
     	self.k = "K"
     	self.l = "L"
     	self.m = "M"
     	self.n = "N"
     	self.o = "O"
     	self.p = "P"
     	self.q = "Q"
     	self.r = "R"
     	self.s = "S"
     	self.t = "T"
     	self.u = "U"
     	self.v = "V"
     	self.w = "W"
     	self.x = "X"
     	self.y = "Y"
     	self.z = "Z"

		@IsSet = Hash.new
     	@IsSet["A"] = false
		@IsSet["B"] = false
		@IsSet["C"] = false
		@IsSet["D"] = false
		@IsSet["E"] = false
		@IsSet["F"] = false
		@IsSet["G"] = false
		@IsSet["H"] = false
		@IsSet["I"] = false
		@IsSet["J"] = false
		@IsSet["K"] = false
		@IsSet["L"] = false
		@IsSet["M"] = false
		@IsSet["N"] = false
		@IsSet["O"] = false
		@IsSet["P"] = false
		@IsSet["Q"] = false
		@IsSet["R"] = false
		@IsSet["S"] = false
		@IsSet["T"] = false
		@IsSet["U"] = false
		@IsSet["V"] = false
		@IsSet["W"] = false
		@IsSet["X"] = false
		@IsSet["Y"] = false
		@IsSet["Z"] = false
    end

end
